% Isotope ratios for mantle (M) and crust (C) reservoir:
% Tune as need to match the mixing curve to the end-points.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
MSr76 = 0.7025;
CSr76 = 0.725;
MNd34 = 0.5131;
CNd34 = 0.5119;
MPb64 = 17.8;
CPb64 = 18.8;
MPb74 = 15.43;
CPb74 = 15.60;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Concentrations for mantle (M) and crust (C) reservoir:
% Again, these can be tuned to match the curvature observed in datasets.
% Provided estimates below from McDonough&Sun and Rudnick&Gao:
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
MSr = 19.9;
CSr = 320;
MNd = 1.25;
CNd = 27;
MPb = 0.15;
CPb = 17;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Define a range of mixing mantle fractions (0 to 1 in 1000 steps):
Mfract = linspace(0,1,1000); 

% Now mix the reservoirs (components):
mixSr76 = (((MSr.*Mfract)./((MSr.*Mfract)+(CSr.*(1-Mfract))))).*MSr76+(((CSr.*(1-Mfract))./((MSr.*Mfract)+(CSr.*(1-Mfract))))).*CSr76;
mixNd34 = (((MNd.*Mfract)./((MNd.*Mfract)+(CNd.*(1-Mfract))))).*MNd34+(((CNd.*(1-Mfract))./((MNd.*Mfract)+(CNd.*(1-Mfract))))).*CNd34;
mixPb64 = (((MPb.*Mfract)./((MPb.*Mfract)+(CPb.*(1-Mfract))))).*MPb64+(((CPb.*(1-Mfract))./((MPb.*Mfract)+(CPb.*(1-Mfract))))).*CPb64;
mixPb74 = (((MPb.*Mfract)./((MPb.*Mfract)+(CPb.*(1-Mfract))))).*MPb74+(((CPb.*(1-Mfract))./((MPb.*Mfract)+(CPb.*(1-Mfract))))).*CPb74;

% Plot the mixtures:
% Sr versus Nd:
figure;plot(mixSr76,mixNd34);
% in epsilon notation:
figure;plot(mixSr76,(1e4.*((mixNd34./0.51264)-1)));
% Pb vs Pb
figure;plot(mixPb64,mixPb74);
% Pb vs Sr
% we'll load a background dataset-image to compare:
figure;
img=imread('Stracke_2005_Sr_Pb_crop.jpg');
image(linspace(16.5,22.5,1177),linspace(0.702,0.709,883),flipud(img));
set(gca,'YDir','normal')                                              
hold on
plot(mixPb64,mixSr76,'r');
